@@ -7,6 +7,6 @@ use encrypt38::{handle_arguments, init_clap};
 fn main() {
     handle_arguments(init_clap().get_matches()).unwrap_or_else(|err| {
         eprintln!("\x1b[31m\x1b[1merror\x1b[m: {}", err);
-        std::process::exit(96);
+        std::process::exit(err.status());
     });
 }
